nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Leftjust

Enum Leftjust 

#[repr(u8)]
pub enum Leftjust { RIGHT_JUSTIFIED = 0, LEFT_JUSTIFIED = 1, }

Variants



RIGHT_JUSTIFIED = 0

Data is transferred between the FIFO and the I2S serializer/deserializer right justified, i.e. starting from bit 0 and continuing to the position defined by DATALEN. This would correspond to right justified data in the stream on the data bus.



LEFT_JUSTIFIED = 1

Data is transferred between the FIFO and the I2S serializer/deserializer left justified, i.e. starting from the MSB of the FIFO entry and continuing for the number of bits defined by DATALEN. This would correspond to left justified data in the stream on the data bus.

Implementations

Source

impl Leftjust

pub const fn from_bits(val: u8) -> Leftjust

pub const fn to_bits(self) -> u8