nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Mode

Enum Mode 

#[repr(u8)]
pub enum Mode { CLASSIC_MODE = 0, DSP_MODE_WS_50_DUTYCYCLE = 1, DSP_MODE_WS_1_CLOCK = 2, DSP_MODE_WS_1_DATA = 3, }

Variants



CLASSIC_MODE = 0

I2S mode a.k.a. ‘classic’ mode. WS has a 50% duty cycle, with (for each enabled channel pair) one piece of left channel data occurring during the first phase, and one pieces of right channel data occurring during the second phase. In this mode, the data region begins one clock after the leading WS edge for the frame. For a 50% WS duty cycle, FRAMELEN must define an even number of I2S clocks for the frame. If FRAMELEN defines an odd number of clocks per frame, the extra clock will occur on the right.



DSP_MODE_WS_50_DUTYCYCLE = 1

DSP mode where WS has a 50% duty cycle. See remark for mode 0.



DSP_MODE_WS_1_CLOCK = 2

DSP mode where WS has a one clock long pulse at the beginning of each data frame.



DSP_MODE_WS_1_DATA = 3

DSP mode where WS has a one data slot long pulse at the beginning of each data frame.

Implementations

Source

impl Mode

pub const fn from_bits(val: u8) -> Mode

pub const fn to_bits(self) -> u8