#[repr(u8)]pub enum Rightlow {
RIGHT_HIGH = 0,
RIGHT_LOW = 1,
}Variants
RIGHT_HIGH = 0
The right channel is taken from the high part of the FIFO data. For example, when data is 16 bits, FIFO bits 31:16 are used for the right channel.
RIGHT_LOW = 1
The right channel is taken from the low part of the FIFO data. For example, when data is 16 bits, FIFO bits 15:0 are used for the right channel.
Implementations